==> llm-docs-0.1.4.tgz: package/docs/components/bfcicomponents/nodejs-build.md <==
---
id: components-bfcicomponents-nodejs-build
---
# Node.js Build Component

The `nodejs-build` component provides standardized build jobs for Node.js projects in GitLab CI/CD pipelines.

## Purpose

This component:

- Provides configurable build jobs for Node.js projects
- Handles TypeScript type checking
- Manages build artifacts
- Supports different build modes and environments
- Works seamlessly with the `nodejs-base` component
- Supports custom Docker image configuration

## Inputs

| Input               | Description                                    | Default                                                                                            | Options                                                   |
| ------------------- | ---------------------------------------------- | -------------------------------------------------------------------------------------------------- | --------------------------------------------------------- |
| `build_script`      | NPM script to run for building the project     | `"build"`                                                                                          | Any script name                                           |
| `build_output_dir`  | Directory containing build output              | `"dist"`                                                                                           | Any directory path                                        |
| `build_mode`        | Build mode                                     | `"production"`                                                                                     | `"production"`, `"development"`, `"test"`                 |
| `build_env_vars`    | Additional environment variables for the build | `""`                                                                                               | Space-separated variables                                 |
| `use_custom_image`  | Use LLM Platform custom Docker image                | `true`                                                                                             | `true`, `false`                                           |
| `custom_image_path` | Path to custom Docker image                    | `"registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest"` | Any valid image path                                      |
| `stage`             | Stage for build jobs                           | `"build"`                                                                                          | Any valid stage name                                      |
| `typecheck`         | Whether to run a TypeScript type check         | `true`                                                                                             | `true`, `false`                                           |
| `lint_before_build` | Whether to run linting before build            | `false`                                                                                            | `true`, `false`                                           |
| `artifact_expire`   | Expiry time for artifacts                      | `"1 week"`                                                                                         | `"1 hour"`, `"1 day"`, `"1 week"`, `"1 month"`, `"never"` |

## Provided Jobs

| Job     | Description                | Conditions         |
| ------- | -------------------------- | ------------------ |
| `build` | Builds the Node.js project | Enabled by default |

## Reusable Job Templates

The component provides these reusable job templates that can be extended in your pipeline:

| Template     | Description             |
| ------------ | ----------------------- |
| `.build_job` | Template for build jobs |

## Custom Docker Image Support

When `use_custom_image` is set to `true`, the component will use the specified custom Docker image instead of the standard Node.js image:

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-build.yml'
    inputs:
      use_custom_image: true
      custom_image_path: 'registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest'
```

## Local Dependency Handling

The component automatically executes a `prepare-ci.sh` script if it exists in the repository root. This ensures local dependencies are properly handled before and after the build process.

## Environment Variables

The following environment variables are set during the build:

- `BUILD_SCRIPT`: Set to the value of `build_script`
- `BUILD_OUTPUT_DIR`: Set to the value of `build_output_dir`
- `BUILD_MODE`: Set to the value of `build_mode`
- `BUILD_ENV_VARS`: Set to the value of `build_env_vars`

## Usage Example

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-base.yml'
    inputs:
      node_version: '20'
      use_custom_image: true
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-build.yml'
    inputs:
      build_script: 'build:prod'
      build_output_dir: 'dist'
      build_mode: 'production'
      use_custom_image: true
```

## Advanced Configuration

### Custom Build Script

To use a custom build script:

```yaml
inputs:
  build_script: 'build:custom'
```

### Environment Variables

To set custom environment variables for the build:

```yaml
inputs:
  build_env_vars: 'API_URL=https://api.example.com DEBUG=false'
```

### Different Build Output Directory

If your project outputs to a different directory:

```yaml
inputs:
  build_output_dir: 'build'
```

### Using Standard Node.js Image

If you need to use the standard Node.js image rather than the custom one:

```yaml
inputs:
  use_custom_image: false
```

## Troubleshooting

### Build Failures

If the build job is failing:

1. Check that the specified build script exists in your package.json
2. Ensure TypeScript configuration is valid if using TypeScript
3. Verify that all dependencies are properly installed by the `install` job

### Artifacts Not Being Saved

If build artifacts aren't being saved:

1. Verify the output directory specified in `build_output_dir` exists after the build
2. Check that the output directory is created during the build process

### Local Dependencies Issues

If builds are failing due to local dependencies:

1. Create a `prepare-ci.sh` script in your project root
2. Implement logic to replace local dependencies with published versions
3. Make the script executable with `chmod +x prepare-ci.sh`

Example `prepare-ci.sh`:

```bash
#!/bin/bash
sed -i 's|"bfcommon": "file:../BFCommon"|"bfcommon": "1.0.0"|g' package.json
```

==> llm-docs-1.0.1.tgz: package/docs/components/bfcicomponents/nodejs-build.md <==
---
id: components-bfcicomponents-nodejs-build
---
# Node.js Build Component

The `nodejs-build` component provides standardized build jobs for Node.js projects in GitLab CI/CD pipelines.

## Purpose

This component:

- Provides configurable build jobs for Node.js projects
- Handles TypeScript type checking
- Manages build artifacts
- Supports different build modes and environments
- Works seamlessly with the `nodejs-base` component
- Supports custom Docker image configuration

## Inputs

| Input               | Description                                    | Default                                                                                            | Options                                                   |
| ------------------- | ---------------------------------------------- | -------------------------------------------------------------------------------------------------- | --------------------------------------------------------- |
| `build_script`      | NPM script to run for building the project     | `"build"`                                                                                          | Any script name                                           |
| `build_output_dir`  | Directory containing build output              | `"dist"`                                                                                           | Any directory path                                        |
| `build_mode`        | Build mode                                     | `"production"`                                                                                     | `"production"`, `"development"`, `"test"`                 |
| `build_env_vars`    | Additional environment variables for the build | `""`                                                                                               | Space-separated variables                                 |
| `use_custom_image`  | Use Bluefly custom Docker image                | `true`                                                                                             | `true`, `false`                                           |
| `custom_image_path` | Path to custom Docker image                    | `"registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest"` | Any valid image path                                      |
| `stage`             | Stage for build jobs                           | `"build"`                                                                                          | Any valid stage name                                      |
| `typecheck`         | Whether to run a TypeScript type check         | `true`                                                                                             | `true`, `false`                                           |
| `lint_before_build` | Whether to run linting before build            | `false`                                                                                            | `true`, `false`                                           |
| `artifact_expire`   | Expiry time for artifacts                      | `"1 week"`                                                                                         | `"1 hour"`, `"1 day"`, `"1 week"`, `"1 month"`, `"never"` |

## Provided Jobs

| Job     | Description                | Conditions         |
| ------- | -------------------------- | ------------------ |
| `build` | Builds the Node.js project | Enabled by default |

## Reusable Job Templates

The component provides these reusable job templates that can be extended in your pipeline:

| Template     | Description             |
| ------------ | ----------------------- |
| `.build_job` | Template for build jobs |

## Custom Docker Image Support

When `use_custom_image` is set to `true`, the component will use the specified custom Docker image instead of the standard Node.js image:

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-build.yml'
    inputs:
      use_custom_image: true
      custom_image_path: 'registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest'
```

## Local Dependency Handling

The component automatically executes a `prepare-ci.sh` script if it exists in the repository root. This ensures local dependencies are properly handled before and after the build process.

## Environment Variables

The following environment variables are set during the build:

- `BUILD_SCRIPT`: Set to the value of `build_script`
- `BUILD_OUTPUT_DIR`: Set to the value of `build_output_dir`
- `BUILD_MODE`: Set to the value of `build_mode`
- `BUILD_ENV_VARS`: Set to the value of `build_env_vars`

## Usage Example

```yaml
include:
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-base.yml'
    inputs:
      node_version: '20'
      use_custom_image: true
  - component: 'gitlab://blueflyio/BFCIComponents/components/nodejs-build.yml'
    inputs:
      build_script: 'build:prod'
      build_output_dir: 'dist'
      build_mode: 'production'
      use_custom_image: true
```

## Advanced Configuration

### Custom Build Script

To use a custom build script:

```yaml
inputs:
  build_script: 'build:custom'
```

### Environment Variables

To set custom environment variables for the build:

```yaml
inputs:
  build_env_vars: 'API_URL=https://api.example.com DEBUG=false'
```

### Different Build Output Directory

If your project outputs to a different directory:

```yaml
inputs:
  build_output_dir: 'build'
```

### Using Standard Node.js Image

If you need to use the standard Node.js image rather than the custom one:

```yaml
inputs:
  use_custom_image: false
```

## Troubleshooting

### Build Failures

If the build job is failing:

1. Check that the specified build script exists in your package.json
2. Ensure TypeScript configuration is valid if using TypeScript
3. Verify that all dependencies are properly installed by the `install` job

### Artifacts Not Being Saved

If build artifacts aren't being saved:

1. Verify the output directory specified in `build_output_dir` exists after the build
2. Check that the output directory is created during the build process

### Local Dependencies Issues

If builds are failing due to local dependencies:

1. Create a `prepare-ci.sh` script in your project root
2. Implement logic to replace local dependencies with published versions
3. Make the script executable with `chmod +x prepare-ci.sh`

Example `prepare-ci.sh`:

```bash
#!/bin/bash
sed -i 's|"bfcommon": "file:../BFCommon"|"bfcommon": "1.0.0"|g' package.json
```
